#!/usr/bin/env python
# coding=utf-8

from setuptools import setup, find_packages

setup(
    name='lunuan',
    version='0.1.2',
    description=('Python开发中常用的类'),
    long_description=(
        'Python开发中常用的类'
    ),
    author='huaxing',
    author_email='huaxing@lunuan.com.cn',
    maintainer='huaxing',
    maintainer_email='huaxing@lunuan.com.cn',
    license='BSD License',
    packages=find_packages(),
    platforms=["all"],
    url=' ',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)
